# Some examples

Here you can find some example programs using the voronoi generator to achieve
different outputs.

Feel free to contribute with example programs. Just make sure they can compile on macOS/Linux/Win32 by adding them to the compile_clang.sh/compile_cl.bat files :)

## [simple.c](./simple.c)

_From the suggestion of [@abetusk](https://github.com/abetusk)_

This example outputs 10 random 2D coordinates, and all the generated edges, to standard output.
Note that the edges have duplicates, but you can easily filter them out.